<?php

namespace Drupal\bibcite_import_orcid\Plugin\Block;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Block\BlockBase;
use Drupal\user\Entity\User;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Provides a block with a ORCID SYNC button.
 *
 * @Block(
 *   id = "bibcite_import_orcid_block",
 *   admin_label = @Translation("ORCID SYNC Button"),
 * )
 */
class OrcidBlock extends BlockBase
{
    /**
     * {@inheritdoc}
     */
    public function build()
    {
        $current_user_id = \Drupal::currentUser()->id();
        $current_user = User::load($current_user_id);
        $current_path = \Drupal::service('path.current')->getPath();
        $path_args = explode('/', $current_path);
        $path_args[2] && $show_block = ($current_user_id == $path_args[2] || $current_user->hasRole('administrator'));

        if($show_block){
        // Return the form @ /Form/ImportForm.php.
        return \Drupal::formBuilder()->getForm('Drupal\bibcite_import_orcid\Form\PrepareImport');
        }
    }
    /**
     * {@inheritdoc}
     */
    protected function blockAccess(AccountInterface $account)
    {
        return AccessResult::allowedIfHasPermission($account, 'access content');
    }
    /**
     * {@inheritdoc}
     */
    public function blockForm($form, FormStateInterface $form_state)
    {
        $config = $this->getConfiguration();

        return $form;
    }

    /**
     * {@inheritdoc}
     */
    public function blockSubmit($form, FormStateInterface $form_state)
    {
        $this->configuration['orcid_block_settings'] = $form_state->getValue('orcid_block_settings');
    }
}
